@@ -26,10 +26,21 @@
 #ifndef __HD_SELECT_PLUGINS_DIALOG_H__
 #define __HD_SELECT_PLUGINS_DIALOG_H__
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
+#ifdef HAVE_LIBOSSOHELP
+#include <libosso.h>
+#endif
+
 #include <gtk/gtk.h>
 
-gint   hd_select_plugins_dialog_run  (GList *loaded_plugins,
-                                      const gchar *plugin_dir,
-                                      GList **selected_plugins);
+gint   hd_select_plugins_dialog_run  (GList           *loaded_plugins,
+#ifdef HAVE_LIBOSSOHELP
+                                      osso_context_t  *osso_context,
+#endif
+                                      const gchar     *plugin_dir,
+				      GList          **selected_plugins);
 
 #endif /* __HD_SELECT_PLUGINS_DIALOG_H__ */
